#!/bin/sh
#
# create.sh: build the standard CMASTRO font sizes.
# Set MODE and GFPOST to your liking below.
#
MODE=localfont
GFPOST="gftopk ./cmastro*.*gf; rm ./cmastro*.*gf"
#
# Generate sizes loaded by astro.tex:
#
rm -f ./tfm/cmastro*.tfm *.log
#
cmmf "\mode=$MODE; mag=magstep 5; input cmastro10"; eval $GFPOST
cmmf "\mode=$MODE; mag=magstep 4; input cmastro10"; eval $GFPOST
cmmf "\mode=$MODE; mag=magstep 3; input cmastro10"; eval $GFPOST
cmmf "\mode=$MODE; mag=magstep 2; input cmastro10"; eval $GFPOST
cmmf "\mode=$MODE; mag=magstep 1; input cmastro10"; eval $GFPOST
cmmf "\mode=$MODE; mag=magstep 0.5; input cmastro10"; eval $GFPOST
cmmf "\mode=$MODE; input cmastro10"; eval $GFPOST
cmmf "\mode=$MODE; input cmastro9"; eval $GFPOST
cmmf "\mode=$MODE; input cmastro8"; eval $GFPOST
cmmf "\mode=$MODE; input cmastro7"; eval $GFPOST
cmmf "\mode=$MODE; input cmastro6"; eval $GFPOST
cmmf "\mode=$MODE; input cmastro5"; eval $GFPOST
#
# move the results to their destination...
#
mv cmastro*.*pk pk
mv cmastro*.tfm tfm
rm -f ./cmastro*.*gf *.log

